@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   __init__.py                                                               #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 '''Redis for Humans.
@@ -12,8 +12,13 @@ know how to use Pottery.
 '''
 
 
+from typing import Tuple
+
+from typing_extensions import Final
+
+
 __title__ = 'pottery'
-__version__ = '1.0.8'
+__version__ = '1.1.5'
 __description__, __long_description__ = (
     s.strip() for s in __doc__.split(sep='\n\n', maxsplit=1)
 )
@@ -22,7 +27,7 @@ __author__ = 'Rajiv Bakulesh Shah'
 __author_email__ = 'brainix@gmail.com'
 __license__ = 'Apache 2.0'
 __keywords__ = 'Redis client persistent storage'
-__copyright__ = f'Copyright © 2015-2020, {__author__}, original author.'
+__copyright__ = f'Copyright © 2015-2021, {__author__}, original author.'
 
 
 from .exceptions import PotteryError  # isort:skip
@@ -40,6 +45,7 @@ from .cache import redis_cache  # isort:skip
 from .hyper import HyperLogLog  # isort:skip
 from .nextid import NextId  # isort:skip
 from .redlock import Redlock  # isort:skip
+from .redlock import synchronize  # isort:skip
 from .timer import ContextTimer  # isort:skip
 
 from .counter import RedisCounter
@@ -49,7 +55,7 @@ from .list import RedisList
 from .set import RedisSet
 
 
-__all__ = [
+__all__: Final[Tuple[str, ...]] = (
     'PotteryError',
     'KeyExistsError',
     'RandomKeyError',
@@ -65,6 +71,7 @@ __all__ = [
     'HyperLogLog',
     'NextId',
     'Redlock',
+    'synchronize',
     'ContextTimer',
 
     'RedisCounter',
@@ -72,4 +79,4 @@ __all__ = [
     'RedisDict',
     'RedisList',
     'RedisSet',
-]
+)
