@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   base.py                                                                   #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 
@@ -20,7 +20,6 @@ from types import TracebackType
 from typing import Any
 from typing import ClassVar
 from typing import ContextManager
-from typing import Dict
 from typing import FrozenSet
 from typing import Generator
 from typing import Iterable
@@ -38,6 +37,8 @@ from redis.client import Pipeline
 from typing_extensions import Final
 
 from . import monkey
+from .annotations import JSONTypes
+from .annotations import RedisValues
 from .exceptions import RandomKeyError
 
 
@@ -52,11 +53,12 @@ def random_key(*,
                length: int = 16,
                num_tries: int = 3,
                ) -> str:
+    'Find/return a random key that does not exist in the Redis instance.'
     if not isinstance(num_tries, int):
         raise TypeError('num_tries must be an int >= 0')
-    elif num_tries < 0:
+    if num_tries < 0:
         raise ValueError('num_tries must be an int >= 0')
-    elif num_tries <= 0:
+    if num_tries == 0:
         raise RandomKeyError(redis)
 
     all_chars = string.digits + string.ascii_letters
@@ -74,6 +76,8 @@ def random_key(*,
 
 
 class _Common:
+    'Mixin class that implements self.redis and self.key properties.'
+
     _RANDOM_KEY_PREFIX: ClassVar[str] = 'pottery:'
 
     def __init__(self,
@@ -124,11 +128,9 @@ class _Common:
     __random_key = _random_key
 
 
-JSONTypes = Union[None, bool, int, float, str, List[Any], Dict[str, Any]]
-RedisValues = Union[bytes, str, float, int]
-
-
 class _Encodable:
+    'Mixin class that implements JSON encoding and decoding.'
+
     @staticmethod
     def _encode(value: JSONTypes) -> str:
         encoded = json.dumps(value, sort_keys=True)
@@ -141,6 +143,8 @@ class _Encodable:
 
 
 class _Comparable(metaclass=abc.ABCMeta):
+    'Mixin class that implements equality testing for Redis-backed collections.'
+
     @property
     @abc.abstractmethod
     def redis(self) -> Redis:
@@ -168,6 +172,8 @@ class _Comparable(metaclass=abc.ABCMeta):
 
 
 class _Clearable(metaclass=abc.ABCMeta):
+    'Mixin class that implements clearing (emptying) a Redis-backed collection.'
+
     @property
     @abc.abstractmethod
     def redis(self) -> Redis:
@@ -184,6 +190,12 @@ class _Clearable(metaclass=abc.ABCMeta):
 
 
 class _ContextPipeline:
+    '''Context manager that sets up, then executes, a Redis pipeline.
+
+    Redis pipelines: https://redis.io/topics/pipelining
+    Redis transactions: https://redis.io/topics/transactions
+    '''
+
     def __init__(self, redis: Redis) -> None:
         self.redis = redis
 
@@ -248,25 +260,28 @@ class _Pipelined(metaclass=abc.ABCMeta):
 
 
 class Base(_Common, _Encodable, _Comparable, _Clearable, _Pipelined):
-    ...
+    'Base class for Redis-backed collections.'
 
 
 class Iterable_(metaclass=abc.ABCMeta):
-    @staticmethod  # pragma: no cover
+    'Mixin class that implements iterating over a Redis-backed collection.'
+
+    @staticmethod
     @abc.abstractmethod
     def _decode(value: bytes) -> JSONTypes:
-        ...
+        raise NotImplementedError
 
-    @property  # pragma: no cover
+    @property
     @abc.abstractmethod
     def key(self) -> str:
         'Redis key.'
+        raise NotImplementedError
 
-    @abc.abstractmethod  # pragma: no cover
+    @abc.abstractmethod
     def _scan(self,
               *, cursor: int = 0,
               ) -> Tuple[int, Union[List[bytes], Mapping[bytes, bytes]]]:
-        ...
+        raise NotImplementedError
 
     def __iter__(self) -> Generator[JSONTypes, None, None]:
         'Iterate over the items in a Redis-backed container.  O(n)'
@@ -279,6 +294,8 @@ class Iterable_(metaclass=abc.ABCMeta):
 
 
 class Primitive(metaclass=abc.ABCMeta):
+    'Base class for Redis-backed distributed primitives.'
+
     _DEFAULT_MASTERS: ClassVar[FrozenSet[Redis]] = frozenset({_default_redis})
 
     def __init__(self,
