@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   bloom.py                                                                  #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 
@@ -15,21 +15,17 @@ from typing import Callable
 from typing import Generator
 from typing import Iterable
 from typing import Set
-from typing import TypeVar
 from typing import cast
 
 import mmh3
 
+from .annotations import F
 from .base import Base
 from .base import JSONTypes
 
 
-# A function that receives *args and **kwargs, and returns anything.  Useful
-# for annotating decorators.
-F = TypeVar('F', bound=Callable[..., Any])
-
-
 def _store_on_self(*, attr: str) -> Callable[[F], F]:
+    "Decorator to store/cache a method's return value as an attribute on self."
     def decorator(func: F) -> F:
         @functools.wraps(func)
         def wrapper(self: Any, *args: Any, **kwargs: Any) -> Any:
@@ -44,6 +40,15 @@ def _store_on_self(*, attr: str) -> Callable[[F], F]:
 
 
 class BloomFilterABC(metaclass=abc.ABCMeta):
+    '''Bloom filter abstract base class.
+
+    This abstract base class:
+        1. Defines the abstract methods that the concrete implementation class
+           must define (having to do with encoding/decoding, I/O, and storage)
+        2. Implements numerical recipes on the number of elements that you want
+           to insert, and the acceptable false positive rate
+    '''
+
     @abc.abstractmethod
     def _bit_offsets(self,
                      encoded_value: JSONTypes,
@@ -51,17 +56,17 @@ class BloomFilterABC(metaclass=abc.ABCMeta):
         for seed in range(self.num_hashes()):
             yield mmh3.hash(encoded_value, seed=seed) % self.size()
 
-    @abc.abstractmethod  # pragma: no cover
+    @abc.abstractmethod
     def update(self, *iterables: Iterable[JSONTypes]) -> None:
-        ...
+        raise NotImplementedError
 
-    @abc.abstractmethod  # pragma: no cover
+    @abc.abstractmethod
     def __contains__(self, value: JSONTypes) -> bool:
-        ...
+        raise NotImplementedError
 
-    @abc.abstractmethod  # pragma: no cover
+    @abc.abstractmethod
     def _num_bits_set(self) -> int:
-        ...
+        raise NotImplementedError
 
     def __init__(self,
                  iterable: Iterable[JSONTypes] = frozenset(),
@@ -70,7 +75,7 @@ class BloomFilterABC(metaclass=abc.ABCMeta):
                  false_positives: float,
                  **kwargs: Any,
                  ) -> None:
-        '''Initialize a BloomFilter.  O(n * k)
+        '''Initialize the BloomFilter.  O(n * k)
 
         Here, n is the number of elements in iterable that you want to insert
         into this Bloom filter, and k is the number of times to run our hash
@@ -119,7 +124,7 @@ class BloomFilterABC(metaclass=abc.ABCMeta):
         return num_hashes
 
     def add(self, value: JSONTypes) -> None:
-        '''Add an element to a BloomFilter.  O(k)
+        '''Add an element to the BloomFilter.  O(k)
 
         Here, k is the number of times to run our hash functions on a given
         input string to compute bit offests into the underlying string
@@ -128,7 +133,7 @@ class BloomFilterABC(metaclass=abc.ABCMeta):
         self.update({value})
 
     def __len__(self) -> int:
-        '''Return the approximate the number of elements in a BloomFilter.  O(m)
+        '''Return the approximate the number of elements in the BloomFilter.  O(m)
 
         Here, m is the size in bits of the underlying string representing this
         Bloom filter.
@@ -253,7 +258,7 @@ class BloomFilter(BloomFilterABC, Base):
         return super()._bit_offsets(encoded_value)
 
     def update(self, *iterables: Iterable[JSONTypes]) -> None:
-        '''Populate a Bloom filter with the elements in iterables.  O(n * k)
+        '''Populate the Bloom filter with the elements in iterables.  O(n * k)
 
         Here, n is the number of elements in iterables that you want to insert
         into this Bloom filter, and k is the number of times to run our hash
@@ -291,11 +296,11 @@ class BloomFilter(BloomFilterABC, Base):
         return self.redis.bitcount(self.key)
 
     def __repr__(self) -> str:
-        'Return the string representation of a BloomFilter.  O(1)'
+        'Return the string representation of the BloomFilter.  O(1)'
         return f'<{self.__class__.__name__} key={self.key}>'
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == '__main__':
     # Run the doctests in this module with:
     #   $ source venv/bin/activate
     #   $ python3 -m pottery.bloom
