@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   cache.py                                                                  #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 
@@ -42,6 +42,11 @@ _logger: Final[logging.Logger] = logging.getLogger('pottery')
 
 
 class CacheInfo(NamedTuple):
+    '''Caching decorator information.
+
+    This CacheInfo named tuple is compatible with the one in functools:
+        https://github.com/python/cpython/blob/7a34380ad788886f5ad50d4175ceb2d5715b8cff/Lib/functools.py#L430
+    '''
     hits: int = 0
     misses: int = 0
     maxsize: Optional[int] = None
@@ -55,7 +60,7 @@ def _arg_hash(*args: Hashable, **kwargs: Hashable) -> int:
 F = TypeVar('F', bound=Callable[..., JSONTypes])
 
 
-def redis_cache(*,
+def redis_cache(*,  # NoQA: C901
                 redis: Optional[Redis] = None,
                 key: Optional[str] = None,
                 timeout: Optional[int] = _DEFAULT_TIMEOUT,
@@ -298,8 +303,7 @@ class CachedOrderedDict(collections.OrderedDict):
         except WatchError:  # pragma: no cover
             if try_num < self._num_tries - 1:
                 return self.__retry(callable, try_num=try_num+1)
-            else:
-                raise
+            raise
 
     @_set_expiration
     def update(self, arg: InitArg = tuple(), **kwargs: JSONTypes) -> None:  # type: ignore
