@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   counter.py                                                                #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 
@@ -87,7 +87,7 @@ class RedisCounter(RedisDict, collections.Counter):
             super().__delitem__(key)
 
     def __repr__(self) -> str:
-        'Return the string representation of a RedisCounter.  O(n)'
+        'Return the string representation of the RedisCounter.  O(n)'
         items = self.most_common()
         pairs = (f"'{key}': {value}" for key, value in items)
         repr_ = ', '.join(pairs)
@@ -103,7 +103,7 @@ class RedisCounter(RedisDict, collections.Counter):
                 for key, value in encoded_dict.items()
             }
             counter.update(decoded_dict)
-            if cursor == 0:  # pragma: no cover
+            if cursor == 0:
                 break
         return counter
 
@@ -126,7 +126,7 @@ class RedisCounter(RedisDict, collections.Counter):
         "Return the subtraction other's counts from our counts, but keep only counts > 0.  O(n)"
         return self.__math_op(other, method=collections.Counter.__sub__)
 
-    def __or__(self, other: Counter[JSONTypes]) -> Counter[JSONTypes]:
+    def __or__(self, other: Counter[JSONTypes]) -> Counter[JSONTypes]:  # type: ignore
         "Return the max of our counts vs. other's counts (union), but keep only counts > 0.  O(n)"
         return self.__math_op(other, method=collections.Counter.__or__)
 
@@ -228,7 +228,7 @@ class RedisCounter(RedisDict, collections.Counter):
                     pipeline.hdel(self.key, *encoded_to_del)
             return self
 
-    def __ior__(self, other: Counter[JSONTypes]) -> Counter[JSONTypes]:
+    def __ior__(self, other: Counter[JSONTypes]) -> Counter[JSONTypes]:  # type: ignore
         'Same as __or__(), but in-place.  O(n)'
         return self.__iset_op(other, method=int.__gt__)
 
