@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   deque.py                                                                  #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 
@@ -9,6 +9,8 @@
 import collections
 from typing import Iterable
 from typing import Optional
+from typing import Tuple
+from typing import Union
 
 from redis import Redis
 from redis.client import Pipeline
@@ -29,7 +31,7 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
                  redis: Optional[Redis] = None,
                  key: Optional[str] = None,
                  ) -> None:
-        'Initialize a RedisDeque.  O(n)'
+        'Initialize the RedisDeque.  O(n)'
         if maxlen is not None and not isinstance(maxlen, int):
             raise TypeError('an integer is required')
         self._maxlen = maxlen
@@ -46,7 +48,7 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
         if self.maxlen is not None:
             if self.maxlen:
                 iterable = tuple(iterable)[-self.maxlen:]
-            else:  # pragma: no cover
+            else:
                 iterable = tuple()
         super()._populate(pipeline, iterable)
 
@@ -62,13 +64,12 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
         )
 
     def insert(self, index: int, value: JSONTypes) -> None:
-        'Insert an element into a RedisDeque before the given index.  O(n)'
+        'Insert an element into the RedisDeque before the given index.  O(n)'
         if self.maxlen is not None and len(self) >= self.maxlen:
             raise IndexError(
                 f'{self.__class__.__name__} already at its maximum size'
             )
-        else:
-            return super()._insert(index, value)
+        return super()._insert(index, value)
 
     def append(self, value: JSONTypes) -> None:
         'Add an element to the right side of the RedisDeque.  O(1)'
@@ -79,11 +80,11 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
         self.__extend((value,), right=False)
 
     def extend(self, values: Iterable[JSONTypes]) -> None:
-        'Extend a RedisList by appending elements from the iterable.  O(1)'
+        'Extend the RedisDeque by appending elements from the iterable.  O(1)'
         self.__extend(values, right=True)
 
     def extendleft(self, values: Iterable[JSONTypes]) -> None:
-        '''Extend a RedisList by prepending elements from the iterable.  O(1)
+        '''Extend the RedisDeque by prepending elements from the iterable.  O(1)
 
         Note the order in which the elements are prepended from the iterable:
 
@@ -100,16 +101,16 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
                  right: bool = True,
                  ) -> None:
         with self._watch(values) as pipeline:
+            push_method = 'rpush' if right else 'lpush'
             encoded_values = [self._encode(value) for value in values]
             len_ = len(self) + len(encoded_values)
-            pipeline.multi()
-            push_method = 'rpush' if right else 'lpush'
-            getattr(pipeline, push_method)(self.key, *encoded_values)
+            trim_indices: Union[Tuple[int, int], Tuple] = tuple()
             if self.maxlen is not None and len_ >= self.maxlen:
-                if right:
-                    trim_indices = len_-self.maxlen, len_
-                else:
-                    trim_indices = 0, self.maxlen-1
+                trim_indices = (len_-self.maxlen, len_) if right else (0, self.maxlen-1)
+
+            pipeline.multi()
+            getattr(pipeline, push_method)(self.key, *encoded_values)
+            if trim_indices:
                 pipeline.ltrim(self.key, *trim_indices)
 
     def pop(self) -> JSONTypes:  # type: ignore
@@ -119,25 +120,39 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
         return super().pop(0)
 
     def rotate(self, n: int = 1) -> None:
-        '''Rotate the RedisDeque n steps to the right (default n=1).
+        '''Rotate the RedisDeque n steps to the right (default n=1).  O(n)
 
         If n is negative, rotates left.
         '''
-        if n:
-            with self._watch() as pipeline:
-                push_method = 'lpush' if n > 0 else 'rpush'
-                values = self[-n:] if n > 0 else self[:-n]
-                encoded_values = (self._encode(element) for element in values)
-                trim_indices = (0, len(self)-n) if n > 0 else (-n, len(self))
+        if not isinstance(n, int):
+            raise TypeError(
+                f"'{n.__class__.__name__}' object cannot be interpreted "
+                'as an integer'
+            )
+        if n == 0:
+            return
 
-                pipeline.multi()
-                getattr(pipeline, push_method)(self.key, *encoded_values)
-                pipeline.ltrim(self.key, *trim_indices)
+        with self._watch() as pipeline:
+            if not self:
+                return
+
+            push_method = 'lpush' if n > 0 else 'rpush'
+            values = self[-n:][::-1] if n > 0 else self[:-n]
+            encoded_values = (self._encode(element) for element in values)
+            trim_indices = (0, len(self)-1) if n > 0 else (-n, len(self)-1-n)
+
+            pipeline.multi()
+            getattr(pipeline, push_method)(self.key, *encoded_values)
+            pipeline.ltrim(self.key, *trim_indices)
 
     # Methods required for Raj's sanity:
 
+    def __bool__(self) -> bool:
+        'Whether the RedisDeque contains any elements.  O(1)'
+        return bool(len(self))
+
     def __repr__(self) -> str:
-        'Return the string representation of a RedisDeque.  O(n)'
+        'Return the string representation of the RedisDeque.  O(n)'
         encoded = self.redis.lrange(self.key, 0, -1)
         values = [self._decode(value) for value in encoded]
         repr = self.__class__.__name__ + '(' + str(values)
