@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   list.py                                                                   #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 
@@ -14,7 +14,6 @@ from typing import Callable
 from typing import Iterable
 from typing import List
 from typing import Optional
-from typing import TypeVar
 from typing import Union
 from typing import cast
 
@@ -22,21 +21,19 @@ from redis import Redis
 from redis import ResponseError
 from redis.client import Pipeline
 
+from .annotations import F
 from .base import Base
 from .base import JSONTypes
 from .exceptions import KeyExistsError
 
 
-F = TypeVar('F', bound=Callable[..., Any])
-
-
 def _raise_on_error(func: F) -> Callable[[F], F]:
     @functools.wraps(func)
     def wrap(*args: Any, **kwargs: Any) -> Any:
         try:
             return func(*args, **kwargs)
-        except ResponseError:
-            raise IndexError('list assignment index out of range')
+        except ResponseError as error:
+            raise IndexError('list assignment index out of range') from error
     return wrap
 
 
@@ -44,14 +41,17 @@ class RedisList(Base, collections.abc.MutableSequence):
     'Redis-backed container compatible with Python lists.'
 
     def __slice_to_indices(self, slice_or_index: Union[slice, int]) -> range:
-        try:
-            start = cast(slice, slice_or_index).start or 0
-            stop = cast(slice, slice_or_index).stop or len(self)
-            step = cast(slice, slice_or_index).step or 1
-        except AttributeError:
-            start = slice_or_index
+        if isinstance(slice_or_index, slice):
+            start, stop, step = cast(slice, slice_or_index).indices(len(self))
+        elif isinstance(slice_or_index, int):
+            start = cast(int, slice_or_index)
             stop = cast(int, slice_or_index) + 1
             step = 1
+        else:
+            raise TypeError(
+                'list indices must be integers or slices, '
+                f'not {slice_or_index.__class__.__name__}'
+            )
         indices = range(start, stop, step)
         return indices
 
@@ -61,21 +61,20 @@ class RedisList(Base, collections.abc.MutableSequence):
                  redis: Optional[Redis] = None,
                  key: Optional[str] = None,
                  ) -> None:
-        'Initialize a RedisList.  O(n)'
+        'Initialize the RedisList.  O(n)'
         super().__init__(redis=redis, key=key)
         if iterable:
             with self._watch(iterable) as pipeline:
                 if pipeline.exists(self.key):
                     raise KeyExistsError(pipeline, self.key)
-                else:
-                    self._populate(pipeline, iterable)
+                self._populate(pipeline, iterable)
 
     def _populate(self,
                   pipeline: Pipeline,
                   iterable: Iterable[JSONTypes] = tuple(),
                   ) -> None:
         encoded_values = [self._encode(value) for value in iterable]
-        if encoded_values:  # pragma: no cover
+        if encoded_values:
             pipeline.multi()
             pipeline.rpush(self.key, *encoded_values)
 
@@ -84,27 +83,29 @@ class RedisList(Base, collections.abc.MutableSequence):
     def __getitem__(self, index: Union[slice, int]) -> Any:
         'l.__getitem__(index) <==> l[index].  O(n)'
         if isinstance(index, slice):
-            # This is monumentally stupid.  Python's list API requires us
-            # to get elements by slice (defined as a start index, a stop
-            # index, and a step).  Of course, Redis allows us to only get
-            # elements by start and stop (no step), because it's Redis.  So
-            # our ridiculous hack is to get all of the elements between
-            # start and stop from Redis, then discard the ones between step
-            # in Python.  More info:
-            # http://redis.io/commands/lrange
+            # Python's list API requires us to get elements by slice (a start
+            # index, a stop index, and a step).  Redis supports only getting
+            # elements by start and stop (no step).  So our workaround is to
+            # get all of the elements between start and stop from Redis, then
+            # discard the ones between step in Python code.  More info:
+            #   http://redis.io/commands/lrange
             with self._watch() as pipeline:
                 indices = self.__slice_to_indices(index)
+                if indices.step >= 0:
+                    start, stop = indices.start, indices.stop-1
+                else:
+                    start, stop = indices.stop+1, indices.start
                 pipeline.multi()
-                pipeline.lrange(self.key, indices[0], indices[-1])
+                pipeline.lrange(self.key, start, stop)
                 encoded = pipeline.execute()[0]
                 encoded = encoded[::index.step]
                 value: Union[List[JSONTypes], JSONTypes] = [self._decode(value) for value in encoded]
         else:
+            index = self.__slice_to_indices(index).start
             encoded = self.redis.lindex(self.key, index)
             if encoded is None:
                 raise IndexError('list index out of range')
-            else:
-                value = self._decode(encoded)
+            value = self._decode(encoded)
         return value
 
     @_raise_on_error
@@ -124,6 +125,7 @@ class RedisList(Base, collections.abc.MutableSequence):
                 if num:
                     pipeline.lrem(self.key, num, 0)
         else:
+            index = self.__slice_to_indices(index).start
             self.redis.lset(self.key, index, self._encode(value))
 
     @_raise_on_error
@@ -133,28 +135,24 @@ class RedisList(Base, collections.abc.MutableSequence):
             self.__delete(pipeline, index)
 
     def __delete(self, pipeline: Pipeline, index: Union[slice, int]) -> None:
-        # This is monumentally stupid.  Python's list API requires us to delete
-        # an element by *index.*  Of course, Redis doesn't support that,
-        # because it's Redis.  Instead, Redis supports deleting an element by
-        # *value.*  So our ridiculous hack is to set l[index] to 0, then to
-        # delete the value 0.
-        #
-        # More info:
+        # Python's list API requires us to delete an element by *index.*  Redis
+        # supports only deleting an element by *value.*  So our workaround is
+        # to set l[index] to 0, then to delete the value 0.  More info:
         #   http://redis.io/commands/lrem
         indices, num = self.__slice_to_indices(index), 0
         pipeline.multi()
         for index in indices:
             pipeline.lset(self.key, index, 0)
             num += 1
-        if num:  # pragma: no cover
+        if num:
             pipeline.lrem(self.key, num, 0)
 
     def __len__(self) -> int:
-        'Return the number of items in a RedisList.  O(1)'
+        'Return the number of items in the RedisList.  O(1)'
         return self.redis.llen(self.key)
 
     def insert(self, index: int, value: JSONTypes) -> None:
-        'Insert an element into a RedisList before the given index.  O(n)'
+        'Insert an element into the RedisList before the given index.  O(n)'
         self.__insert(index, value)
 
     def _insert(self, index: int, value: JSONTypes) -> None:
@@ -162,15 +160,12 @@ class RedisList(Base, collections.abc.MutableSequence):
         if index <= 0:
             self.redis.lpush(self.key, encoded_value)
         elif index < len(self):
-            # This is monumentally stupid.  Python's list API requires us to
-            # insert an element before the given *index.*  Of course, Redis
-            # doesn't support that, because it's Redis.  Instead, Redis
-            # supports inserting an element before a given (pivot) *value.*  So
-            # our ridiculous hack is to set the pivot value to 0, then to
-            # insert the desired value and the original pivot value before the
-            # value 0, then to delete the value 0.
-            #
-            # More info:
+            # Python's list API requires us to insert an element before the
+            # given *index.*  Redis supports only inserting an element before a
+            # given (pivot) *value.*  So our workaround is to set the pivot
+            # value to 0, then to insert the desired value before the value 0,
+            # then to set the value 0 back to the original pivot value.  More
+            # info:
             #   http://redis.io/commands/linsert
             with self._watch() as pipeline:
                 pivot = self._encode(self[index])
@@ -189,11 +184,10 @@ class RedisList(Base, collections.abc.MutableSequence):
     # Methods required for Raj's sanity:
 
     def sort(self, *, key: Optional[str] = None, reverse: bool = False) -> None:
-        'Sort a RedisList in place.  O(n)'
-        if key is None:
-            self.redis.sort(self.key, desc=reverse, store=self.key)
-        else:
+        'Sort the RedisList in place.  O(n)'
+        if key is not None:
             raise NotImplementedError('sorting by key not implemented')
+        self.redis.sort(self.key, desc=reverse, store=self.key)
 
     def __eq__(self, other: Any) -> bool:
         if super().__eq__(other):
@@ -219,13 +213,13 @@ class RedisList(Base, collections.abc.MutableSequence):
                 return False
 
     def __add__(self, other: List[JSONTypes]) -> 'RedisList':
-        'Append the items in other to a RedisList.  O(n)'
+        'Append the items in other to the RedisList.  O(n)'
         with self._watch(other):
             iterable = itertools.chain(self, other)
             return self.__class__(iterable, redis=self.redis)
 
     def __repr__(self) -> str:
-        'Return the string representation of a RedisList.  O(n)'
+        'Return the string representation of the RedisList.  O(n)'
         encoded = self.redis.lrange(self.key, 0, -1)
         with self._watch():
             values = [self._decode(value) for value in encoded]
@@ -240,7 +234,7 @@ class RedisList(Base, collections.abc.MutableSequence):
 
     # From collections.abc.MutableSequence:
     def extend(self, values: Iterable[JSONTypes]) -> None:
-        'Extend a RedisList by appending elements from the iterable.  O(1)'
+        'Extend the RedisList by appending elements from the iterable.  O(1)'
         encoded_values = (self._encode(value) for value in values)
         self.redis.rpush(self.key, *encoded_values)
 
@@ -261,8 +255,7 @@ class RedisList(Base, collections.abc.MutableSequence):
                     raise IndexError(
                         f'pop from an empty {self.__class__.__name__}'
                     )
-                else:
-                    return self._decode(encoded_value)
+                return self._decode(encoded_value)
             else:
                 value: JSONTypes = self[cast(int, index)]
                 self.__delete(pipeline, cast(int, index))
@@ -274,10 +267,10 @@ class RedisList(Base, collections.abc.MutableSequence):
             for index, element in enumerate(self):
                 if element == value:
                     self.__delete(pipeline, index)
-                    break
-            else:
-                class_ = self.__class__.__name__
-                raise ValueError(f'{class_}.remove(x): x not in {class_}')
+                    return
+        class_name = self.__class__.__name__
+        raise ValueError(f'{class_name}.remove(x): x not in {class_name}')
 
     def to_list(self) -> List[JSONTypes]:
+        'Convert the RedisList to a Python list.  O(n)'
         return list(self)
