@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   nextid.py                                                                 #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 '''Distributed Redis-powered monotonically increasing ID generator.
@@ -122,8 +122,7 @@ class NextId(Primitive):
                 next_id = self.__current_id + 1
                 self.__current_id = next_id
                 return next_id
-        else:
-            raise QuorumNotAchieved(self.masters, self.key)
+        raise QuorumNotAchieved(self.key, self.masters)
 
     def __repr__(self) -> str:
         return (
@@ -144,7 +143,11 @@ class NextId(Primitive):
                 try:
                     current_id = int(future.result())
                 except RedisError as error:
-                    _logger.error(error, exc_info=True)
+                    _logger.exception(
+                        '%s.__current_id() getter caught an %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
                 else:
                     current_ids.append(current_id)
 
@@ -152,8 +155,7 @@ class NextId(Primitive):
         quorum = num_masters_gotten >= len(self.masters) // 2 + 1
         if quorum:
             return max(current_ids)
-        else:
-            raise QuorumNotAchieved(self.masters, self.key)
+        raise QuorumNotAchieved(self.key, self.masters)
 
     @__current_id.setter
     def __current_id(self, value: int) -> None:
@@ -175,17 +177,21 @@ class NextId(Primitive):
                 try:
                     num_masters_set += future.result() == value
                 except RedisError as error:
-                    _logger.error(error, exc_info=True)
+                    _logger.exception(
+                        '%s.__current_id() setter caught an %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
                 else:
                     quorum = num_masters_set >= len(self.masters) // 2 + 1
                     if quorum:  # pragma: no cover
                         break
 
         if not quorum:
-            raise QuorumNotAchieved(self.masters, self.key)
+            raise QuorumNotAchieved(self.key, self.masters)
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == '__main__':
     # Run the doctests in this module with:
     #   $ source venv/bin/activate
     #   $ python3 -m pottery.nextid
