@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   redlock.py                                                                #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 '''Distributed Redis-powered lock.
@@ -24,11 +24,14 @@ Lua scripting:
 
 import concurrent.futures
 import contextlib
+import functools
 import logging
 import os
 import random
 import time
 from types import TracebackType
+from typing import Any
+from typing import Callable
 from typing import ClassVar
 from typing import Iterable
 from typing import Optional
@@ -40,6 +43,7 @@ from redis import RedisError
 from redis.client import Script
 from typing_extensions import Final
 
+from .annotations import F
 from .base import Primitive
 from .exceptions import ExtendUnlockedLock
 from .exceptions import ReleaseUnlockedLock
@@ -48,6 +52,9 @@ from .executor import BailOutExecutor
 from .timer import ContextTimer
 
 
+AUTO_RELEASE_TIME: Final[int] = 10 * 1000
+
+
 _logger: Final[logging.Logger] = logging.getLogger('pottery')
 
 
@@ -127,7 +134,6 @@ class Redlock(Primitive):
     '''
 
     KEY_PREFIX: ClassVar[str] = 'redlock'
-    AUTO_RELEASE_TIME: ClassVar[int] = 10 * 1000
     CLOCK_DRIFT_FACTOR: ClassVar[float] = 0.01
     RETRY_DELAY: ClassVar[int] = 200
     NUM_EXTENSIONS: ClassVar[int] = 3
@@ -261,7 +267,11 @@ class Redlock(Primitive):
                 try:
                     num_masters_acquired += future.result()
                 except RedisError as error:  # pragma: no cover
-                    _logger.error(error, exc_info=True)
+                    _logger.exception(
+                        '%s.__acquire_masters() caught an %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
                 else:
                     quorum = num_masters_acquired >= len(self.masters) // 2 + 1
                     if quorum:
@@ -271,10 +281,10 @@ class Redlock(Primitive):
 
         if quorum and max(validity_time, 0):
             return True
-        else:
-            with contextlib.suppress(ReleaseUnlockedLock):
-                self.__release()
-            return False
+
+        with contextlib.suppress(ReleaseUnlockedLock):
+            self.__release()
+        return False
 
     def acquire(self, *, blocking: bool = True, timeout: int = -1) -> bool:
         '''Lock the lock.
@@ -325,13 +335,13 @@ class Redlock(Primitive):
                 while timeout == -1 or timer.elapsed() / 1000 < timeout:
                     if self.__acquire_masters():
                         return True
-                    else:
-                        time.sleep(random.uniform(0, self.RETRY_DELAY/1000))
+                    time.sleep(random.uniform(0, self.RETRY_DELAY/1000))
             return False
-        elif timeout == -1:
+
+        if timeout == -1:
             return self.__acquire_masters()
-        else:
-            raise ValueError("can't specify a timeout for a non-blocking call")
+
+        raise ValueError("can't specify a timeout for a non-blocking call")
 
     __acquire = acquire
 
@@ -373,7 +383,11 @@ class Redlock(Primitive):
                 try:
                     ttls.append(future.result())
                 except RedisError as error:  # pragma: no cover
-                    _logger.error(error, exc_info=True)
+                    _logger.exception(
+                        '%s.locked() caught an %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
 
             num_masters_acquired = sum(1 for ttl in ttls if ttl > 0)
             quorum = num_masters_acquired >= len(self.masters) // 2 + 1
@@ -382,8 +396,8 @@ class Redlock(Primitive):
                 validity_time = ttls[len(self.masters) // 2]
                 validity_time -= round(timer.elapsed() + self.__drift())
                 return max(validity_time, 0)
-            else:
-                return 0
+
+            return 0
 
     __locked = locked
 
@@ -406,30 +420,33 @@ class Redlock(Primitive):
             >>> printer_lock.release()
         '''
         if self._extension_num >= self.num_extensions:
-            raise TooManyExtensions(self.masters, self.key)
-        else:
-            quorum = False
+            raise TooManyExtensions(self.key, self.masters)
+        quorum = False
 
-            with BailOutExecutor() as executor:
-                futures = set()
-                for master in self.masters:
-                    future = executor.submit(self.__extend_master, master)
-                    futures.add(future)
+        with BailOutExecutor() as executor:
+            futures = set()
+            for master in self.masters:
+                future = executor.submit(self.__extend_master, master)
+                futures.add(future)
 
-                num_masters_extended = 0
-                for future in concurrent.futures.as_completed(futures):
-                    try:
-                        num_masters_extended += future.result()
-                    except RedisError as error:  # pragma: no cover
-                        _logger.error(error, exc_info=True)
-                    else:
-                        quorum = num_masters_extended >= len(self.masters) // 2 + 1
-                        if quorum:
-                            break
+            num_masters_extended = 0
+            for future in concurrent.futures.as_completed(futures):
+                try:
+                    num_masters_extended += future.result()
+                except RedisError as error:  # pragma: no cover
+                    _logger.exception(
+                        '%s.extend() caught an %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
+                else:
+                    quorum = num_masters_extended >= len(self.masters) // 2 + 1
+                    if quorum:
+                        break
 
-            self._extension_num += quorum
-            if not quorum:
-                raise ExtendUnlockedLock(self.masters, self.key)
+        self._extension_num += quorum
+        if not quorum:
+            raise ExtendUnlockedLock(self.key, self.masters)
 
     def release(self) -> None:
         '''Unlock the lock.
@@ -460,14 +477,18 @@ class Redlock(Primitive):
                 try:
                     num_masters_released += future.result()
                 except RedisError as error:  # pragma: no cover
-                    _logger.error(error, exc_info=True)
+                    _logger.exception(
+                        '%s.release() caught an %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
                 else:
                     quorum = num_masters_released >= len(self.masters) // 2 + 1
                     if quorum:
                         break
 
         if not quorum:
-            raise ReleaseUnlockedLock(self.masters, self.key)
+            raise ReleaseUnlockedLock(self.key, self.masters)
 
     __release = release
 
@@ -529,7 +550,50 @@ class Redlock(Primitive):
         )
 
 
-if __name__ == '__main__':  # pragma: no cover
+def synchronize(*,
+                key: str,
+                masters: Iterable[Redis] = frozenset(),
+                auto_release_time: int = AUTO_RELEASE_TIME,
+                ) -> Callable[[F], F]:
+    '''Decorator to synchronize a function's execution across threads.
+
+    synchronize() is a decorator that allows only one thread to execute a
+    function at a time.  Under the hood, synchronize() uses a Redlock.  See
+    help(Redlock) for more details.
+
+    Usage:
+
+        >>> @synchronize(key='synchronized-func', auto_release_time=1500)
+        ... def func():
+        ...     # Only one thread can execute this function at a time.
+        ...     return True
+        ...
+        >>> func()
+        True
+    '''
+    def decorator(func: F) -> F:
+        @functools.wraps(func)
+        def wrapper(*args: Any, **kwargs: Any) -> Any:
+            redlock = Redlock(
+                key=key,
+                masters=masters,
+                auto_release_time=auto_release_time,
+            )
+            with ContextTimer() as timer, redlock:
+                return_value = func(*args, **kwargs)
+
+            _logger.info(
+                '%s() held %s for %d ms',
+                func.__qualname__,
+                redlock.key,
+                timer.elapsed(),
+            )
+            return return_value
+        return cast(F, wrapper)
+    return decorator
+
+
+if __name__ == '__main__':
     # Run the doctests in this module with:
     #   $ source venv/bin/activate
     #   $ python3 -m pottery.redlock
