@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------- #
 #   timer.py                                                                  #
 #                                                                             #
-#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
 # --------------------------------------------------------------------------- #
 'Measure the execution time of small code snippets.'
@@ -92,7 +92,7 @@ class ContextTimer:
             raise RuntimeError("timer hasn't yet been started")
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == '__main__':
     # Run the doctests in this module with:
     #   $ source venv/bin/activate
     #   $ python3 -m pottery.timer
